@@ -98,7 +98,7 @@ def transfer(files: List[str],
 
 def load_config_check():
     cfg = load_config()
-    if not cfg.offline:
+    if not cfg.offline and cfg.check_version:
         exception_to_message()(check_version)(cfg.repo_url)
     return cfg
 
