@@ -7,7 +7,7 @@ import urllib
 from pathlib import Path
 from typing import List, Optional, Tuple, Union
 import warnings
-from functools import wraps
+from functools import wraps, partial
 
 import gpg_lite as gpg
 from libbiomedit import crypt
@@ -35,10 +35,14 @@ def to_user_error(error_types: Union[Exception, Tuple[Exception, ...]]):
 
 validate_pub_key = to_user_error(RuntimeError)(crypt.validate_pub_key)
 validated_keys_by_ids = to_user_error(
-    (RuntimeError, gpg.cmd.GPGError))(crypt.validated_keys_by_ids)
+    (RuntimeError, gpg.cmd.GPGError))(
+        partial(crypt.validated_keys_by_ids, url_opener=urlopen))
 refresh_keys = to_user_error(
-    (RuntimeError, gpg.cmd.GPGError))(crypt.refresh_keys)
+    (RuntimeError, gpg.cmd.GPGError))(
+        partial(crypt.refresh_keys, url_opener=urlopen))
 fingerprint2keyid = to_user_error(RuntimeError)(crypt.fingerprint2keyid)
+verify_metadata_signature = to_user_error(
+    RuntimeError)(crypt.verify_metadata_signature)
 
 
 @to_user_error(gpg.cmd.GPGError)
@@ -108,22 +112,6 @@ def check_password(user_fingerprint: str, passphrase: str,
         raise UserError("GPG password is incorrect")
 
 
-def verify_signature(src: Union[bytes, io.IOBase], sig: bytes,
-                     gpg_store: GPGStore) -> str:
-    """Verify a file with a detached signature.
-
-    :param src: file object of bytes to be verified.
-    :param sig: signature to be used for verification.
-    :param gpg_store: key database as gnupg object.
-    :return: fingerprint of the key used for the signature.
-    :raises UserError:
-    """
-    try:
-        return gpg_store.verify(src, sig)
-    except gpg.cmd.GPGError as e:
-        raise UserError(f"Signature verification failed. {e}")
-
-
 class KeyType(enum.Enum):
     public = enum.auto()
     secret = enum.auto()
