@@ -84,7 +84,7 @@ class MainWindow(QtWidgets.QMainWindow):
             event.ignore()
 
     def check_version(self):
-        if self.app_data.config.offline:
+        if self.app_data.config.offline or not self.app_data.config.check_version:
             return
         def get_warnings():
             with warnings.catch_warnings(record=True) as w:
@@ -891,7 +891,7 @@ class KeysTab(QtWidgets.QWidget):
 
     def update_private_keys(self):
         # Retrieve all private keys from local keyring.
-        keys_private = self.app_data.config.gpg_store.list_sec_keys(keys=())
+        keys_private = self.app_data.config.gpg_store.list_sec_keys()
         try:
             default_key = (self.app_data.config.default_sender or
                            self.app_data.config.gpg_store.default_key())
@@ -905,8 +905,7 @@ class KeysTab(QtWidgets.QWidget):
 
     def update_public_keys(self):
         # Retrieve all public keys from local keyring.
-        keys_public = self.app_data.config.gpg_store.list_pub_keys(keys=(),
-                                                                   sigs=True)
+        keys_public = self.app_data.config.gpg_store.list_pub_keys(sigs=True)
         self.app_data.pub_keys_model.set_data(
             {f"{key.uids[0]} {key.key_id}": key for key in keys_public})
 
@@ -966,7 +965,7 @@ class KeysTab(QtWidgets.QWidget):
         msg_warn = QtWidgets.QMessageBox()
         msg_warn.setWindowTitle("GPG key deletion error")
         msg_warn.setIcon(QtWidgets.QMessageBox.Warning)
-        priv_keys = self.app_data.config.gpg_store.list_sec_keys(keys=())
+        priv_keys = self.app_data.config.gpg_store.list_sec_keys()
         for index in self.pub_keys_view.selectedIndexes():
             key = index.model().get_value(index)
             if any(k for k in priv_keys if key.fingerprint == k.fingerprint):
