@@ -4,6 +4,7 @@ from typing import Callable, Iterable, List, Optional, Tuple
 
 from PySide2 import QtCore, QtWidgets
 
+from .parallel import Worker
 from ..utils.progress import ProgressInterface
 
 
@@ -172,3 +173,34 @@ class PathInput:
     def on_path_change(self, fn: Callable[[Optional[Path]], None]) -> None:
         """Run callback when path changes."""
         self.text.editingFinished.connect(lambda: fn(self.path))
+
+
+class TabMixin:
+    def create_console(self):
+        self.console = ConsoleWidget("Console", self)
+
+    def create_progress_bar(self):
+        self.progress_bar = QtWidgets.QProgressBar(self)
+        self.progress_bar.hide()
+
+    def create_run_panel(self, panel_name: str, action: Callable,
+                         action_name: str):
+        self.run_panel = QtWidgets.QGroupBox(panel_name)
+        layout = QtWidgets.QHBoxLayout()
+        self.btn_test = QtWidgets.QPushButton("Test")
+        self.btn_test.clicked.connect(partial(action, dry_run=True))
+        self.btn_run = QtWidgets.QPushButton(action_name)
+        self.btn_run.clicked.connect(action)
+        layout.addWidget(self.btn_test)
+        layout.addWidget(self.btn_run)
+        self.run_panel.setLayout(layout)
+
+    def add_worker_actions(self, worker: Worker):
+        """Attach GUI-updating signals to worker"""
+        worker.signals.started.connect(self.progress_bar.show)
+        worker.signals.started.connect(lambda: self.run_panel.setEnabled(False))
+        worker.signals.logging.connect(self.console.write)
+        worker.signals.error.connect(lambda e: self.console.append(str(e[1])))
+        worker.signals.finished.connect(lambda: self.progress_bar.setValue(0))
+        worker.signals.finished.connect(self.progress_bar.hide)
+        worker.signals.finished.connect(lambda: self.run_panel.setEnabled(True))
