@@ -1,15 +1,14 @@
 import os
 import json
-import tarfile
 
 from typing import List, Optional
 
 from ..core.error import UserError
 from ..core.archive import check_tar, unpack, extract, \
-    METADATA_FILE, METADATA_FILE_SIG, DATA_ARCHIVE, DATA_FILE_ENCRYPTED, \
+    METADATA_FILE, DATA_ARCHIVE, DATA_FILE_ENCRYPTED, \
     CHECKSUM_FILE
 from ..core.crypt import decrypt as core_decrypt, extract_pub_key_ids, \
-    validated_keys_by_ids, verify_signature, fingerprint2keyid
+    validated_keys_by_ids, fingerprint2keyid, verify_metadata_signature
 from ..core.filesystem import delete_files
 from ..core.checksum import verify_checksums, compute_checksum_sha256, read_checksum_file
 from ..core.metadata import MetaData
@@ -21,24 +20,6 @@ from ..utils.config import Config
 logger = create_logger(__name__)
 
 
-def verify_metadata_signature(tar_file, config):
-    """Check if the metadata file has been signed."""
-    with tarfile.open(tar_file) as tar:
-        try:
-            sig = tar.extractfile(METADATA_FILE_SIG).read()
-            if not sig:
-                raise UserError(
-                    f"{tar_file}: Metadata is not signed by the sender")
-        except KeyError:
-            raise UserError(f"{tar_file}: Metadata signature not found")
-        fpr = verify_signature(tar.extractfile(METADATA_FILE), sig,
-                               config.gpg_store)
-        validated_keys_by_ids((fpr,),
-                              config.gpg_store,
-                              config.key_validation_authority_keyid,
-                              config.keyserver_url)
-
-
 @logger.exception_to_message((UserError, FileNotFoundError))
 def decrypt(files: List[str],
             *,
@@ -65,7 +46,10 @@ def decrypt(files: List[str],
         return
 
     for tar_file in files:
-        verify_metadata_signature(tar_file, config)
+        verify_metadata_signature(
+            tar_file, config.gpg_store,
+            config.key_validation_authority_keyid,
+            config.keyserver_url)
 
     decrypted_tars = []
     for tar in progress_file_iter(files, progress=progress, mode='rb'):
